@@ -342,7 +342,7 @@ sub create_accessor {
     my $strage;
     if ($accessor_type eq 'ClassAttr') {
         # Strage package Varialbe in case class accessor
-        $strage = "Object::Simple::Util->class_infos->{\$self}{class_attrs}{'$accessor_name'}";
+        $strage = "Object::Simple::Util->class_attrs(\$self)->{'$accessor_name'}";
         $source .=
                 qq/    Carp::croak("${class}::$accessor_name must be called from class, not instance")\n/ .
                 qq/      if ref \$self;\n/;
@@ -766,7 +766,11 @@ sub class_attrs {
     
     my $class = ref $invocant || $invocant;
     
-    return $self->class_infos->{$class}{class_attrs};
+    no strict 'refs';
+    ${"${class}::CLASS_ATTRS"} ||= {};
+    my $class_attrs = ${"${class}::CLASS_ATTRS"};
+    
+    return $class_attrs;
 }
 
 # Class attribute is exsist?
@@ -775,7 +779,7 @@ sub exists_class_attr {
     
     my $class = ref $invocant || $invocant;
 
-    return exists $self->class_infos->{$class}{class_attrs}{$accessor_name};
+    return exists $self->class_attrs($class)->{$accessor_name};
 }
 
 # Delete class attribute
@@ -784,7 +788,18 @@ sub delete_class_attr {
 
     my $class = ref $invocant || $invocant;
 
-    return delete $self->class_infos->{$class}{class_attrs}{$accessor_name};
+    return delete $self->class_attrs($class)->{$accessor_name};
+}
+
+sub init_attrs {
+    
+    my ($self, $obj, @attrs) = @_;
+    
+    foreach my $attr (@attrs) {
+        $obj->$attr($obj->{$attr}) if exists $obj->{$attr};
+    }
+    
+    return $self;
 }
 
 =head1 NAME
@@ -793,6 +808,12 @@ Object::Simple::Util - Object::Simple utility
 
 =head1 Methods
 
+=head2 init_attrs
+
+initalize attribute
+
+    Object::Simple::Util->init_attrs($self, qw/title author/);
+
 =head2 check_accessor_option
 
 =head2 class_attrs
